@@ -169,22 +169,16 @@ class TestPatterns(unittest.TestCase):
 
             self.assertEqual(len(s), r.raw.pattern_ascii_pointer_1(astr))
 
-
-    # def test_options(self):
-    #     inner = r.Inner()
-    #     option = r.Op
-
     def test_api_entry(self):
-        pointers = r.Pointers()
-        tuple = r.Tupled()
+        api = r.MyAPIv1()
+        r.raw.my_api_init_v1(api.ptr())
 
-        tuple.x0 = 123
+        t = r.Tupled()
+        t.x0 = 10
 
-        r.raw.api_entry_points(pointers.ptr())
-
-        print(pointers._ctx)
-        tuple2 = pointers.f2(tuple._ctx[0])
-        print(tuple2.x0)
+        # TODO: The ptr()[0] part is a bit ugly ... should fix
+        t2 = api.tupled(t.ptr()[0])
+        self.assertEqual(20, t2.x0)
 
 
 if __name__ == '__main__':
